NAME
IWL::SubmitImage - an image used as a submit button
INHERITANCE
IWL::Object -> IWL::Widget -> IWL::Input -> IWL::SubmitImage
IWL::Object -> IWL::Widget -> IWL::Image -> IWL::SubmitImage
DESCRIPTION
The SubmitImage widget functions as a widget, which when pressed, activates the submit of the form
CONSTRUCTOR
IWL::SubmitImage->new ([%ARGS])
Where %ARGS is an optional hash parameter with with key-values.
LICENCE AND COPYRIGHT
Copyright (c) 2006-2007 Viktor Kojouharov. All rights reserved.
This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself. See perldoc perlartistic.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.